# Kata
[![Travis](https://img.shields.io/travis/FlorianKempenich/kata.svg)](https://travis-ci.org/FlorianKempenich/kata) [![PyPI](https://img.shields.io/pypi/v/kata.svg)](https://pypi.org/project/kata/)

Kata: A single command to get a ready to use TDD setup for your Kata, in your language of choice



---
## Author Information
Follow me on Twitter: [@ThisIsFlorianK](https://twitter.com/ThisIsFlorianK)  
Find out more about my work: [Florian Kempenich — Personal Website](https://floriankempenich.com)
